import subprocess
import json
import os

# Define translations
translations = {
    'en': {
        'no_updates': "No updates available",
        'updates_available': "updates available",
        'pkcon': "PKCON",
        'flatpak': "Flatpak"
    },
    'pt': {
        'no_updates': "Nenhuma atualização disponível",
        'updates_available': "atualizações disponíveis",
        'pkcon': "PKCON",
        'flatpak': "Flatpak"
    },
    'es': {
        'no_updates': "No hay actualizaciones disponibles",
        'updates_available': "actualizaciones disponibles",
        'pkcon': "PKCON",
        'flatpak': "Flatpak"
    }
}

def get_system_language():
    lang = os.environ.get('LANG', 'en_US.UTF-8')
    if lang.startswith('pt'):
        return 'pt'
    elif lang.startswith('es'):
        return 'es'
    else:
        return 'en'

def count_flatpak_updates():
    env = os.environ.copy()
    env['LANG'] = 'en_US.UTF-8'
    # Run the flatpak update command with --appstream and --dry-run options
    result = subprocess.run(
        ["flatpak", "remote-ls", "--updates"],
        capture_output=True,
        text=True,
        env=env
    )
    return len(result.stdout.splitlines())

def count_pkcon_updates():
    env = os.environ.copy()
    env['LANG'] = 'en_US.UTF-8'
    pkcon_updates = subprocess.run(['pkcon', 'get-updates'], capture_output=True, text=True, env=env)
    pkcon_update_lines = pkcon_updates.stdout.splitlines()
    pkcon_update_count = 0
    results_found = False
    for line in pkcon_update_lines:
        if results_found:
            pkcon_update_count += 1
        if line.startswith('Results:'):
            results_found = True
        if line.startswith('There are no updates available at this time.'):
            results_found = False
            pkcon_update_count = 0
    return pkcon_update_count

def check_updates():    
    # Check for pkcon updates
    pkcon_update_count = count_pkcon_updates()
    
    # Check for flatpak updates
    flatpak_update_count = count_flatpak_updates()
    
    return pkcon_update_count, flatpak_update_count

def main():
    # Get the system language
    lang = get_system_language()
    
    pkcon_update_count, flatpak_update_count = check_updates()
    total_updates = pkcon_update_count + flatpak_update_count
    
    # Output for Waybar
    if total_updates > 0:
        print(json.dumps({
            "text": f" {total_updates}",
            "tooltip": f"{translations[lang]['pkcon']}: {pkcon_update_count}, {translations[lang]['flatpak']}: {flatpak_update_count}",
            "class": "updates-available",
            "percentage": "0"
        }))
    else:
        print(json.dumps({
            "text": "",
            "tooltip": translations[lang]['no_updates'],
            "class": "no-updates",
            "percentage": "0"
        }))

if __name__ == "__main__":
    main()
